@@ -1,25 +1,13 @@
 #!/usr/bin/perl
 #------------------------------------------------------------------------------------------------------
-# OBJET : Exemple d'utilisation de CTM::ReadEM : recuperation des services du BIM
-#------------------------------------------------------------------------------------------------------
+# OBJET : Exemple d'utilisation de CTM::ReadEM : simple recuperation des services du BIM au format JSON
 # APPLICATION : ControlM
-#------------------------------------------------------------------------------------------------------
 # AUTEUR : Yoann Le Garff
 # DATE DE CREATION : 20/07/2014
-# ETAT : STABLE
 #------------------------------------------------------------------------------------------------------
 # AIDE :
 #   perldoc get_bim_services.pl
 #------------------------------------------------------------------------------------------------------
-# USAGE
-#   ./get_bim_services.pl -x <version_de_ControlM_EM> -h <serveur> [-T <type_de_SGBD>] [-p <port>] -u <utilisateur> [-P <mot_de_passe>] -i <instance> [-t <timeout>] [-V] (verbose)
-#------------------------------------------------------------------------------------------------------
-# DEPENDANCES OBLIGATOIRES
-#   - Getopt::Long
-#   - File::Basename
-#   - Try::Tiny
-#   - CTM::ReadEM
-#------------------------------------------------------------------------------------------------------
 
 #-> BEGIN
 
@@ -31,7 +19,8 @@ use strict;
 use Getopt::Long;
 use File::Basename qw/basename/;
 use Try::Tiny;
-use CTM::ReadEM qw/:all/;
+use JSON;
+use CTM::ReadEM 0.18, qw/:all/;
 
 #----> ** fonctions **
 
@@ -52,7 +41,8 @@ my %opts = (
     P => 'root',
     i => undef,
     t => 60,
-    V => undef
+    f => undef,
+    V => undef,
 );
 
 Getopt::Long::Configure('bundling'); # case sensitive
@@ -65,6 +55,7 @@ GetOptions(
     'P=s' => \$opts{P},
     'i=s' => \$opts{i},
     't=i' => \$opts{t},
+    'f=s' => \$opts{f},
     'V' => \$opts{V},
     'help' => sub {
         print usage() . "\n";
@@ -89,14 +80,19 @@ try {
     die $_ . '. ' . usage();
 };
 
-$session->connectToDB() || die $session->getError() . '. ' . usage();
+$session->connect() || die $session->getError() . '. ' . usage();
 
-my $servicesHashRef = $session->getCurrentServices();
+my $servicesObj = $session->workOnCurrentBIMServices();
 
 print "\n" if (defined $opts{V});
 
 unless (defined ($err = $session->getError())) {
-    print $_->{service_name} . ' : ' . getStatusColorForService($_) . "\n" for (values %{$servicesHashRef});
+    if (defined $opts{f}) {
+        $servicesObj->keepItemsWithAnd({
+            service_name => ['$_', '=~', $opts{f}]
+        });
+    }
+    print JSON->new()->pretty()->encode($servicesObj->getItems()) . "\n";
 } else {
     die $err;
 }
@@ -115,11 +111,11 @@ get_bim_services.pl
 
 =head1 SYNOPSIS
 
-Exemple d utilisation de C<CTM::ReadEM> : recuperation des services du BIM.
+Exemple d utilisation de C<CTM::ReadEM> : simple recuperation des services du BIM au format JSON.
 
 =head1 DEPENDANCES
 
-C<Getopt::Long>, C<File::Basename>, C<Try::Tiny>, C<CTM::ReadEM>
+C<Getopt::Long>, C<File::Basename>, C<Try::Tiny>, C<JSON>, C<CTM::ReadEM>
 
 =head1 USAGE
 
@@ -132,10 +128,15 @@ C<Getopt::Long>, C<File::Basename>, C<Try::Tiny>, C<CTM::ReadEM>
     [-P <mot de passe>]
     -i <instance>
     [-t <timeout>]
+    [-f <service_name - filtre : regexp>]
     [-V] (verbose)
 
 Pour les valeurs par defaut, voir les valeurs de la table de hachage %opts depuis le code source de ce script.
 
+=head1 LIENS
+
+- Depot GitHub : http://github.com/le-garff-yoann/CTM
+
 =head1 AUTEUR
 
 Le Garff Yoann <pe.weeble@yahoo.fr>
