@@ -1,24 +1,12 @@
 #------------------------------------------------------------------------------------------------------
 # OBJET : Module du constructeur CTM::ReadEM::workOnExceptionAlerts()
-#------------------------------------------------------------------------------------------------------
-# APPLICATION : Control-M EM + Configuration Manager Alarms
-#------------------------------------------------------------------------------------------------------
+# APPLICATION : Control-M EM + Configuration Manager Alarms (CM)
 # AUTEUR : Yoann Le Garff
 # DATE DE CREATION : 27/05/2014
-# ETAT : STABLE
 #------------------------------------------------------------------------------------------------------
 # USAGE / AIDE
 #   perldoc CTM::ReadEM::WorkOnExceptionAlerts
 #------------------------------------------------------------------------------------------------------
-# DEPENDANCES OBLIGATOIRES
-#   - CTM::Base
-#   - CTM::Base::SubClass
-#   - Carp
-#   - Hash::Util
-#------------------------------------------------------------------------------------------------------
-# ATTENTION
-#   Ce module n'a pas pour but d'etre directement charge par l'utilisateur
-#------------------------------------------------------------------------------------------------------
 
 #-> BEGIN
 
@@ -35,7 +23,6 @@ use base qw/
 /;
 
 use Carp qw/
-    carp
     croak
 /;
 use Hash::Util qw/
@@ -44,30 +31,31 @@ use Hash::Util qw/
 
 #----> ** variables de classe **
 
-our $VERSION = 0.1771;
+our $VERSION = 0.18;
 
 #----> ** methodes publiques **
 
-sub refresh {
-    return shift->SUPER::_refresh('workOnExceptionAlerts');
+sub resetAndRefresh {
+    return shift->SUPER::_resetAndRefresh(CTM::Base::_CLASS_INFOS->{GASExceptionAlerts}->{workMethod});
 }
 
 sub handle {
-    return shift->SUPER::_setSerials('handle', 'workOnExceptionAlerts', 'ExceptionAlerts', "UPDATE exception_alerts SET status = '2'", @_);
+    return shift->SUPER::_setSerials((caller 0)[3], "UPDATE exception_alerts SET status = '2'", @_);
 }
 
 sub unhandle {
-    return shift->SUPER::_setSerials('unhandle', 'workOnExceptionAlerts', 'ExceptionAlerts', "UPDATE exception_alerts SET status = '1'", @_);
+    return shift->SUPER::_setSerials((caller 0)[3], "UPDATE exception_alerts SET status = '1'", @_);
 }
 
 sub detete {
-    return shift->SUPER::_setSerials('detete', 'workOnExceptionAlerts', 'ExceptionAlerts', 'DELETE FROM exception_alerts', @_);
+    return shift->SUPER::_setSerials((caller 0)[3], 'DELETE FROM exception_alerts', @_);
 }
 
 sub setNote {
     my ($self, $note, $serialID) = @_;
-    croak(CTM::Base::_myErrorMessage('setNote', "usage : la 'note' ne peut pas valoir undef.")) unless (defined $note);
-    return shift->SUPER::_setSerials('setNote', 'workOnExceptionAlerts', 'ExceptionAlerts', "UPDATE exception_alerts SET note = '" . $note . "'", $serialID);
+    my $subName = (caller 0)[3];
+    croak(CTM::Base::_myErrorMessage($subName, CTM::Base::_myUsageMessage('$obj->' . $subName, '$definedNote'))) unless (defined $note);
+    return shift->SUPER::_setSerials($subName, "UPDATE exception_alerts SET note = '" . $note . "'", $serialID);
 }
 
 #-> Perl BuiltIn
@@ -90,21 +78,31 @@ __END__
 
 =head1 NOM
 
-C<CTM::ReadEM::WorkOnExceptionAlerts>
+CTM::ReadEM::WorkOnExceptionAlerts
 
 =head1 SYNOPSIS
 
 Module du constructeur C<CTM::ReadEM::workOnExceptionAlerts()>.
 Pour plus de details, voir la documention POD de C<CTM::ReadEM>.
 
-=head1 DEPENDANCES
+=head1 DEPENDANCES DIRECTES
 
-C<CTM::Base>, C<CTM::Base::SubClass>, C<Carp>, C<Hash::Util>
+C<CTM::Base>
+
+C<CTM::Base::SubClass>
+
+C<Carp>
+
+C<Hash::Util>
 
 =head1 NOTES
 
 Ce module est dedie au module C<CTM::ReadEM>.
 
+=head1 LIENS
+
+- Depot GitHub : http://github.com/le-garff-yoann/CTM
+
 =head1 AUTEUR
 
 Le Garff Yoann <pe.weeble@yahoo.fr>
